@@ -1,4 +1,4 @@
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
 
-import utils as utils
\ No newline at end of file
+from . import utils as utils
\ No newline at end of file
